@@ -41,7 +41,7 @@ bsmc.internal <- function (object, params, Np, est,
 
     ep <- paste0("in ",sQuote("bsmc"),": ")
 
-    pompLoad(object)
+    pompLoad(object,verbose=verbose)
 
     gnsi.rproc <- gnsi.dmeas <- as.logical(.getnativesymbolinfo)
     ptsi.inv <- ptsi.for <- TRUE
@@ -356,7 +356,7 @@ bsmc.internal <- function (object, params, Np, est,
     ## replace parameters with point estimate (posterior median)
     coef(object,transform=transform) <- apply(params,1,median)
 
-    pompUnload(object)
+    pompUnload(object,verbose=verbose)
 
     new(
         "bsmcd.pomp",
