@@ -107,11 +107,11 @@ pomp(
      data=read.csv2(text=dat),
      times="time",
      t0=0,
-     rprocess=discrete.time.sim("ou2_step",PACKAGE="pomp"),
-     dprocess=onestep.dens("ou2_pdf",PACKAGE="pomp"),
-     dmeasure = "ou2_dmeasure",
-     rmeasure = "ou2_rmeasure",
-     skeleton = map("ou2_skel",delta.t=1),
+     rprocess=discrete.time.sim("_ou2_step",PACKAGE="pomp"),
+     dprocess=onestep.dens("_ou2_pdf",PACKAGE="pomp"),
+     dmeasure = "_ou2_dmeasure",
+     rmeasure = "_ou2_rmeasure",
+     skeleton = map("_ou2_skel",delta.t=1),
      PACKAGE="pomp",
      paramnames = c(
        "alpha.1","alpha.2","alpha.3","alpha.4",
