@@ -45,9 +45,6 @@ static const R_CallMethodDef callMethods[] = {
 void R_init_pomp (DllInfo *info) {
   // C functions provided for users
   R_RegisterCCallable("pomp","periodic_bspline_basis_eval",(DL_FUNC) &periodic_bspline_basis_eval);
-  R_RegisterCCallable("pomp","dot_product",(DL_FUNC) &dot_product);
-  R_RegisterCCallable("pomp","reulermultinom",(DL_FUNC) &reulermultinom);
-  R_RegisterCCallable("pomp","deulermultinom",(DL_FUNC) &deulermultinom);
   R_RegisterCCallable("pomp","get_pomp_userdata",(DL_FUNC) &get_pomp_userdata);
   R_RegisterCCallable("pomp","get_pomp_userdata_int",(DL_FUNC) &get_pomp_userdata_int);
   R_RegisterCCallable("pomp","get_pomp_userdata_double",(DL_FUNC) &get_pomp_userdata_double);
