@@ -197,7 +197,7 @@ SEXP do_init_state (SEXP object, SEXP params, SEXP t0, SEXP nsim, SEXP gnsi)
 	cidx = INTEGER(PROTECT(name_index(Cnames,pompfun,"covarnames","covariates"))); nprotect++;
 	
 	// address of native routine
-	ff = (pomp_initializer *) R_ExternalPtrAddr(fn);
+	*((void **) (&ff)) = R_ExternalPtrAddr(fn);
 	
 	nvar = LENGTH(Snames);
 	xdim[0] = nvar; xdim[1] = ns;
